@@ -16,6 +16,8 @@ class CleanCookiesMiddleware(object):
     Clean declined cookies or non accepted cookies if not
     COOKIE_CONSENT_OPT_OUT set.
     """
+    def __init__(self, get_response):
+        self.get_response = get_response
 
     def process_response(self, request, response):
         if not is_cookie_consent_enabled(request):
@@ -31,8 +33,9 @@ class CleanCookiesMiddleware(object):
                 if group_version == settings.COOKIE_CONSENT_DECLINE:
                     response.delete_cookie(smart_str(cookie.name),
                                            cookie.path, cookie.domain)
-                if group_version < cookie.get_version():
-                    if not settings.COOKIE_CONSENT_OPT_OUT:
-                        response.delete_cookie(smart_str(cookie.name),
-                                               cookie.path, cookie.domain)
+                if group_version < cookie.get_version() and not settings.COOKIE_CONSENT_OPT_OUT:
+                    response.delete_cookie(
+                        smart_str(cookie.name),
+                        cookie.path, cookie.domain
+                    )
         return response
