@@ -41,7 +41,7 @@ class CookieGroup(models.Model):
         verbose_name_plural = _('Cookie Groups')
         ordering = ['ordering']
 
-    def __unicode__(self):
+    def __str__(self):
         return self.name
 
     def get_version(self):
@@ -62,7 +62,8 @@ class CookieGroup(models.Model):
 class Cookie(models.Model):
     cookiegroup = models.ForeignKey(
         CookieGroup,
-        verbose_name=CookieGroup._meta.verbose_name)
+        verbose_name=CookieGroup._meta.verbose_name,
+        on_delete=models.CASCADE)
     name = models.CharField(_('Name'), max_length=250)
     description = models.TextField(_('Description'), blank=True)
     path = models.TextField(_('Path'), blank=True, default="/")
@@ -74,7 +75,7 @@ class Cookie(models.Model):
         verbose_name_plural = _('Cookies')
         ordering = ['-created']
 
-    def __unicode__(self):
+    def __str__(self):
         return "%s %s%s" % (self.name, self.domain, self.path)
 
     @property
@@ -105,9 +106,12 @@ class LogItem(models.Model):
     action = models.IntegerField(_('Action'), choices=ACTION_CHOICES)
     cookiegroup = models.ForeignKey(
         CookieGroup,
-        verbose_name=CookieGroup._meta.verbose_name)
+        verbose_name=CookieGroup._meta.verbose_name,
+        on_delete=models.CASCADE)
     version = models.CharField(_('Version'), max_length=32)
     created = models.DateTimeField(_('Created'), auto_now_add=True, blank=True)
+    def __str__(self):
+        return "%s %s" % (self.cookiegroup.name, self.version)
 
     class Meta:
         verbose_name = _('Log item')
