@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 from __future__ import unicode_literals
 
-from django.conf.urls import patterns, url
+from django.conf.urls import url
 from django.views.decorators.csrf import csrf_exempt
 
 from .views import (
@@ -10,8 +10,7 @@ from .views import (
     CookieGroupDeclineView,
 )
 
-urlpatterns = patterns(
-    '',
+urlpatterns = [
     url(r'^accept/$',
         csrf_exempt(CookieGroupAcceptView.as_view()),
         name='cookie_consent_accept_all'),
@@ -27,4 +26,4 @@ urlpatterns = patterns(
     url(r'^$',
         CookieGroupListView.as_view(),
         name='cookie_consent_cookie_group_list'),
-)
+]
